<template>
  <el-card shadow="never" class="aui-card--fill">
    <div class="mod-app">
      <el-form :inline="true" :model="dataForm" @keyup.enter.native="getDataList()">
        <el-form-item>
          <span>时间：</span>
          <el-date-picker
              v-model="dataForm.startTime"
              type="datetime"
              :clearable="true"
              value-format="yyyy-MM-dd HH:mm:ss"
              placeholder="请选择">
          </el-date-picker>
        </el-form-item>
        <el-form-item>
          <span>至</span>
        </el-form-item>
        <el-form-item>
          <el-date-picker
              v-model="dataForm.endTime"
              type="datetime"
              :clearable="true"
              value-format="yyyy-MM-dd HH:mm:ss"
              placeholder="请选择">
          </el-date-picker>
        </el-form-item>
        <el-form-item>
          <el-button @click="getDataList()">{{ $t('query') }}</el-button>
        </el-form-item>
        <el-form-item>
          <el-button type="primary" @click="openForm()">{{ $t('add') }}</el-button>
        </el-form-item>
      </el-form>
      <el-table
          id="listTable"
          v-loading="dataListLoading"
          :data="dataList"
          border
          style="width: 100%;">
        <el-table-column type="index" header-align="center" align="center" width="50" label="序号"></el-table-column>
        <el-table-column prop="lsh" header-align="center" align="center" label="流水号" width="200"></el-table-column>
        <el-table-column prop="rq" header-align="center" align="center" label="日期" width="100"></el-table-column>
        <el-table-column prop="bcName" header-align="center" align="center" label="班次" width="80"></el-table-column>
        <el-table-column prop="czbName" header-align="center" align="center" label="参数名称" width="180"></el-table-column>
        <el-table-column prop="jgzbName" header-align="center" align="center" label="单位" width="180"></el-table-column>
        <el-table-column prop="jkyName" header-align="center" align="center" label="参数值" width="180"></el-table-column>
        <el-table-column prop="content" header-align="center" align="center" label="备注" width="297"></el-table-column>
        <el-table-column :label="$t('handle')" fixed="right" header-align="center" align="center" width="100">
          <template slot-scope="scope">
            <el-button v-if="$hasPermission('sys:user:update')" type="text" size="small" @click="openForm(scope.row.id)">修改</el-button>
            <el-button v-if="$hasPermission('sys:user:delete')" type="text" size="small" @click="handleDelete(scope.row.id)">删除</el-button>
          </template>
        </el-table-column>
      </el-table>
      <!-- 弹窗, 新增 / 修改 -->
      <add-or-update v-if="addOrUpdateVisible" ref="addOrUpdate" @refreshDataList="getDataList"></add-or-update>
   
      <el-pagination  
          :current-page="page"
          :page-sizes="[10, 20, 50, 100]"
          :page-size="limit"
          :total="total"
          layout="total, sizes, prev, pager, next, jumper"
          @size-change="pageSizeChangeHandle"
          @current-change="pageCurrentChangeHandle">
      </el-pagination>
    </div>
  </el-card>
</template>

<script>
import mixinViewModule from '@/mixins/view-module'
import AddOrUpdate from './list-add-or-update'
import {getEndTime, getStartTime} from "@/utils/dateUtils";
export default {
  mixins: [mixinViewModule],
  data () {
    return {
      mixinViewModuleOptions: {
        getDataListURL: '/iailab-iems-coal-proddisp/prod/standing-book/on-duty-info/list',
        getDataListIsPage: true,
        deleteURL: '/iailab-iems-coal-proddisp/prod/standing-book/on-duty-info',
        deleteIsBatch: true,
      },
      dataForm: {
        startTime: getStartTime(),
        endTime: getEndTime()
      }
    }
  },
  components: {
    AddOrUpdate
  },
  methods: {
  }
}
</script>
